// src/json.ts
function tryParseJson(value, defaultValue = null) {
  try {
    const parsed = JSON.parse(value);
    if (parsed === void 0 || parsed === null) {
      return defaultValue;
    }
    return parsed;
  } catch (err) {
    return defaultValue;
  }
}

// src/retry.ts
async function retryWhenFailed(fn, maxRetries = 5, initialSleepTime = 1e3, stopOnError) {
  let attempt = 0;
  while (attempt < maxRetries) {
    try {
      return await fn();
    } catch (e) {
      if (typeof stopOnError === "function") {
        const error = e;
        if (stopOnError(error)) {
          throw error;
        }
      }
      attempt += 1;
      if (attempt >= maxRetries) {
        throw e;
      }
      const jitter = Math.random();
      const delay = 2 ** attempt * initialSleepTime * jitter;
      await new Promise((resolve) => setTimeout(resolve, delay));
    }
  }
  throw new Error("Retry failed");
}

// src/string.ts
function capitalizeFirstLetter(val) {
  return String(val).charAt(0).toUpperCase() + String(val).slice(1);
}
function camelCaseToWords(s) {
  const result = s.replace(/([a-z])([A-Z])/g, "$1 $2");
  const withSpaces = result.replace(/([A-Z])([a-z])/g, " $1$2");
  const capitalized = capitalizeFirstLetter(withSpaces);
  return capitalized.replace(/\s+/g, " ").trim();
}
function replaceUnderscoresAndHyphensWithSpaces(s) {
  return s.replace(/[-_]/g, " ");
}
function truncate(value, maxLength) {
  if (value.length <= maxLength) {
    return value;
  }
  return `${value.slice(0, maxLength)}...`;
}
export {
  camelCaseToWords,
  capitalizeFirstLetter,
  replaceUnderscoresAndHyphensWithSpaces,
  retryWhenFailed,
  truncate,
  tryParseJson
};
//# sourceMappingURL=index.mjs.map